@@ -96,7 +96,7 @@ class SchedulerTask:
                     priority=16,
                     listening_events=[SchedulerTaskExecute],
                     headless_decoraters=self.decorators,
-                    enableInternalAccess=self.enableInternalAccess
+                    enable_internal_access=self.enableInternalAccess
                 ),
                 event=SchedulerTaskExecute()
             ), False, None)
@@ -149,4 +149,4 @@ class SchedulerTask:
     
     def stop(self):
         if not self.task.cancelled():
-            self.task.cancel()
\ No newline at end of file
+            self.task.cancel()
